@@ -638,8 +638,8 @@ def _create_draft(args: Namespace):
 		except Exception as ex:
 			raise se.RemoteCommandErrorException(f"Couldn’t download Project Gutenberg ebook metadata page. Exception: {ex}")
 
-		parser = etree.HTMLParser()
-		dom = etree.parse(StringIO(pg_metadata_html), parser)
+		html_parser = etree.HTMLParser()
+		dom = etree.parse(StringIO(pg_metadata_html), html_parser)
 
 		# Get the ebook HTML URL from the metadata
 		pg_ebook_url = None
@@ -695,11 +695,19 @@ def _create_draft(args: Namespace):
 	if args.pg_id and pg_ebook_html:
 		pg_file_local_path = content_path / "epub" / "text" / "body.xhtml"
 		try:
-			dom = etree.parse(StringIO(regex.sub(r"encoding=(?P<quote>[\'\"]).+?(?P=quote)", "", pg_ebook_html)), parser)
+			dom = etree.parse(StringIO(regex.sub(r"encoding=(?P<quote>[\'\"]).+?(?P=quote)", "", pg_ebook_html)), html_parser)
 			namespaces = {"re": "http://exslt.org/regular-expressions"}
 
 			for node in dom.xpath("//*[re:test(text(), '\\*\\*\\*\\s*Produced by.+')]", namespaces=namespaces):
-				producers_text = regex.sub(r"^<[^>]+?>", "", etree.tostring(node, encoding=str, with_tail=False))
+				node_html = etree.tostring(node, encoding=str, method="html", with_tail=False)
+
+				# Sometimes, lxml returns the entire HTML instead of the node HTML for a node.
+				# It's unclear why this happens. An example is https://www.gutenberg.org/ebooks/21721
+				# If the HTML is larger than some large size, abort trying to find producers
+				if len(node_html) > 3000:
+					continue
+
+				producers_text = regex.sub(r"^<[^>]+?>", "", node_html)
 				producers_text = regex.sub(r"<[^>]+?>$", "", producers_text)
 
 				producers_text = regex.sub(r".+?Produced by (.+?)\s*$", "\\1", producers_text, flags=regex.DOTALL)
@@ -739,6 +747,9 @@ def _create_draft(args: Namespace):
 			# lxml can also output duplicate default namespace declarations so remove the first one only
 			output = regex.sub(r"(xmlns=\".+?\")(\sxmlns=\".+?\")+", r"\1", output)
 
+			# lxml may also create duplicate xml:lang attributes on the root element. Not sure why. Remove them.
+			output = regex.sub(r'(xml:lang="[^"]+?" lang="[^"]+?") xml:lang="[^"]+?"', r"\1", output)
+
 		except Exception as ex:
 			# Save this error for later; we still want to save the book text and complete the
 			#  create-draft process even if we've failed to parse PG's HTML source.
@@ -885,7 +896,7 @@ def _create_draft(args: Namespace):
 		metadata_xml = metadata_xml.replace("SE_IDENTIFIER", identifier)
 		metadata_xml = metadata_xml.replace(">TITLE_SORT<", f">{escape(sorted_title)}<")
 		metadata_xml = metadata_xml.replace(">TITLE<", f">{escape(title)}<")
-		metadata_xml = metadata_xml.replace("VCS_IDENTIFIER", str(repo_name))
+		metadata_xml = metadata_xml.replace("VCS_IDENTIFIER", str(repo_name[0:100]))
 
 		if pg_producers:
 			producers_xhtml = ""
