@@ -3,12 +3,14 @@
 Defines various functions useful for image processing tasks common to epubs.
 """
 
+import base64
 from pathlib import Path
 import tempfile
 import struct
+import urllib.parse
 
 from html import unescape
-from typing import List, Callable, Dict
+from typing import List, Callable, Dict, Union
 import regex
 from PIL import Image, ImageMath, PngImagePlugin, UnidentifiedImageError
 import importlib_resources
@@ -17,6 +19,44 @@ from lxml import etree
 import se
 import se.formatting
 
+def get_data_url(image_path: Path) -> str:
+	"""
+	Return a data URL for the contents of a given image path.
+
+	INPUTS
+	image_path: A path to an image.
+
+	OUTPUTS
+	A string representing the data URL, in the format `data:image/TYPE;ENCODING,CONTENTS`
+	"""
+	data_url = ""
+
+	# SVGs can be inlined as utf8 data, which results in a much smaller file.
+	# Other images are converted to base64 first.
+	if image_path.suffix == ".svg":
+		with open(image_path, "r") as file:
+			svg_contents = file.read()
+
+			# Try to find the encoding of the XML file, default to utf-8
+			encoding="utf-8"
+			matches = regex.search(r"""^<\?xml[^>]*?encoding="([^"]+?)"[^>]*?\?>""", svg_contents)
+			if matches and matches[1]:
+				encoding = urllib.parse.quote(matches[1])
+
+			svg_uri = urllib.parse.quote(svg_contents.replace("\n", ""), safe="")
+
+			data_url = f"data:image/svg+xml;encoding={encoding},{svg_uri}"
+	else:
+		with open(image_path, "rb") as binary_file:
+			mime_type = f"image/{image_path.suffix.replace('.', '')}"
+
+			if image_path.suffix == ".jpg":
+				mime_type = "image/jpeg"
+
+			data_url = f"data:{mime_type};base64,{base64.b64encode(binary_file.read()).decode()}"
+
+	return data_url
+
 def _color_to_alpha(image: Image, color=None) -> Image:
 	"""
 	Implements GIMP's color to alpha algorithm.
@@ -104,15 +144,18 @@ def _color_to_alpha(image: Image, color=None) -> Image:
 
 	return new_image
 
-def has_transparency(filename: Path) -> bool:
+def has_transparency(file: Union[Path, Image.Image]) -> bool:
 	"""
 	Return True if the given image file has transparency
 	"""
 
-	try:
-		image = Image.open(filename)
-	except UnidentifiedImageError as ex:
-		raise se.InvalidFileException(f"Couldn’t identify image type of [path][link=file://{filename.resolve()}]{filename}[/].") from ex
+	image = file
+
+	if isinstance(image, Path):
+		try:
+			image = Image.open(file)
+		except UnidentifiedImageError as ex:
+			raise se.InvalidFileException(f"Couldn’t identify image type of [path][link=file://{file.resolve()}]{file}[/].") from ex
 
 	if image.mode == "P":
 		transparent = image.info.get("transparency", -1)
