@@ -213,18 +213,18 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Nn])ew comer(s?)\b", r"\1ewcomer\2", xhtml)		# new comer -> newcomer
 	xhtml = regex.sub(r"\b([Pp])ease\b(?![ \-]pudding)", r"\1eas", xhtml)		# pease -> peas (but "pease pudding")
 	xhtml = regex.sub(r"\b([Ss])uch like\b", r"\1uchlike", xhtml)			# such like -> suchlike
-	xhtml = regex.sub(r"\b([Ee])mployé", r"\1mployee", xhtml)			# employé -> employee
+	xhtml = regex.sub(r"\b([Ee])mploy[eé](s?)\b", r"\1mployee\2", xhtml)		# employé -> employee
 	xhtml = regex.sub(r"\b(?<!ancien )([Rr])égime", r"\1egime", xhtml)		# régime -> regime (but "ancien régime")
 	xhtml = regex.sub(r"\b([Bb])urthen", r"\1urden", xhtml)				# burthen -> burden
 	xhtml = regex.sub(r"\b([Dd])isburthen", r"\1isburden", xhtml)			# disburthen -> disburden
 	xhtml = regex.sub(r"\b([Uu])nburthen", r"\1nburden", xhtml)			# unburthen -> unburden
 	xhtml = regex.sub(r"\b[EÉ]lys[eé]e", r"Élysée", xhtml)				# Elysee -> Élysée
 	xhtml = regex.sub(r"\b([Ll])aw suit", r"\1awsuit", xhtml)			# law suit -> lawsuit
-	xhtml = regex.sub(r"\bIncase", r"Encase", xhtml)				# Incase -> Encase
-	xhtml = regex.sub(r"\bincase", r"encase", xhtml)				# incase -> encase
-	xhtml = regex.sub(r"\bInclose", r"Enclose", xhtml)				# Inclose -> Enclose
-	xhtml = regex.sub(r"\binclose", r"enclose", xhtml)				# inclose -> enclose
-	xhtml = regex.sub(r"\b([Cc])ocoa-?nut", r"\1oconut", xhtml)			# cocoanut / cocoa-nut -> coconut
+	xhtml = regex.sub(r"\bIncas(es?|ed|ing)", r"Encas\1", xhtml)			# Incase -> Encase
+	xhtml = regex.sub(r"\bincas(es?|ed|ing)", r"encas\1", xhtml)			# incase -> encase
+	xhtml = regex.sub(r"\bInclos(es?|ed?|ures?|ing)\b", r"Enclos\1", xhtml)		# Inclose -> Enclose
+	xhtml = regex.sub(r"\binclos(es?|ed?|ures?|ing)\b", r"enclos\1", xhtml)		# inclose -> enclose
+	xhtml = regex.sub(r"\b([Cc])ocoa[ -]?nut", r"\1oconut", xhtml)			# cocoanut / cocoa-nut -> coconut
 	xhtml = regex.sub(r"\b([Ww])aggon", r"\1agon", xhtml)				# waggon -> wagon
 	xhtml = regex.sub(r"\b([Ss])wop", r"\1wap", xhtml)				# swop -> swap
 	xhtml = regex.sub(r"\b([Ll])acquey", r"\1ackey", xhtml)				# lacquey -> lackey
@@ -252,7 +252,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Mm])esalliance", r"\1ésalliance", xhtml)		# mesalliance -> mésalliance
 	xhtml = regex.sub(r"\b([Ss])ate\b", r"\1at", xhtml)				# sate -> sat
 	xhtml = regex.sub(r"\b([Aa])ttache\b", r"\1ttaché", xhtml)			# attache -> attaché
-	xhtml = regex.sub(r"\b([Pp])orte[\- ]coch[eè]re\b", r"\1orte-cochère", xhtml)	# porte-cochere -> porte-cochère
+	xhtml = regex.sub(r"\b([Pp])orte(s?)[\- ]coch[eè]re(s?)\b", r"\1orte\2-cochère\3", xhtml)	# porte-cochere -> porte-cochère
 	xhtml = regex.sub(r"\b([Nn])[eé]glig[eé]e?(s?)\b", r"\1egligee\2", xhtml)	# négligée -> negligee
 	xhtml = regex.sub(r"\b([Ss])hort cut(s?)\b", r"\1hortcut\2", xhtml)		# short cut -> shortcut
 	xhtml = regex.sub(r"\b([Ff])ocuss", r"\1ocus", xhtml)				# focuss -> focus
@@ -323,7 +323,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Ss])lily", r"\1lyly", xhtml)				# slily -> slyly
 	xhtml = regex.sub(r"\b([Ff])oretel\b", r"\1oretell", xhtml)			# foretel -> foretell
 	xhtml = regex.sub(r"\b([Cc])ypher", r"\1ipher", xhtml)				# cypher -> cipher
-	xhtml = regex.sub(r"\b([Dd])ivers\b", r"\1iverse", xhtml)			# divers -> diverse
+	# xhtml = regex.sub(r"\b([Dd])ivers\b", r"\1iverse", xhtml)			# divers -> diverse NOTE: these two are not the same word! https://www.merriam-webster.com/dictionary/divers "Divers is not a misspelling of diverse—it is a word in its own right."
 	xhtml = regex.sub(r"\b([Ll])anthorn", r"\1antern", xhtml)			# lanthorn -> lantern
 	xhtml = regex.sub(r"\b([Oo])rgie\b", r"\1rgy", xhtml)				# orgie -> orgy
 	xhtml = regex.sub(r"\b([Oo])u?rang[\s-][Oo]utang?", r"\1rangutan", xhtml)	# ourang-outang -> orangutan
@@ -374,6 +374,8 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"incumber", r"encumber", xhtml)				# incumber -> encumber
 	xhtml = regex.sub(r"\bCadi\b", r"Qadi", xhtml)					# cadi -> qadi
 	xhtml = regex.sub(r"\bcadi\b", r"qadi", xhtml)					# cadi -> qadi
+	xhtml = regex.sub(r"\bSoldan(s?)\b", r"Sultan\1", xhtml)			# soldan -> sultan
+	xhtml = regex.sub(r"\bsoldan(s?)\b", r"sultan\1", xhtml)			# soldan -> sultan
 	xhtml = regex.sub(r"\b([Pp])edler", r"\1eddler", xhtml)				# pedler -> peddler
 	xhtml = regex.sub(r"\b([Cc])aldron(s?)", r"\1auldron\2", xhtml)			# caldron -> cauldron
 	xhtml = regex.sub(r"\b([Tt])hru\b", r"\1hru", xhtml)				# thru -> through
@@ -386,7 +388,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"([Pp])ourtray", r"\1ortray", xhtml)				# pourtray -> portray
 	xhtml = regex.sub(r"([S])toopid", r"\1tupid", xhtml)				# stoopid -> stupid
 	xhtml = regex.sub(r"([S])uède", r"\1uede", xhtml)				# suède -> suede
-	xhtml = regex.sub(r"([Ff])or ever\b",r"\1orever", xhtml)			# for ever -> forever
+	xhtml = regex.sub(r"([Ff])or ever\b(?!\s+so long)",r"\1orever", xhtml)		# for ever -> forever
 	xhtml = regex.sub(r"([Dd])ébris\b", r"\1ebris", xhtml)				# débris -> debris
 	xhtml = regex.sub(r"\b([Tt])ho(['’]|\b)(?!\.</abbr>)", r"\1hough", xhtml)	# tho' -> though
 	xhtml = regex.sub(r"\b([Aa])ntient", r"\1ncient", xhtml)			# antient -> ancient
@@ -395,7 +397,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Rr])ibb?and", r"\1ibbon", xhtml)			# ribband -> ribbon (note: `ribband` has a legitimate 2nd meaning but it's extremely rare)
 	xhtml = regex.sub(r"\b([Gg])rewsome", r"\1ruesome", xhtml)			# grewsome -> gruesome
 	xhtml = regex.sub(r"([^’]\b[Tt])il\b", r"\1ill", xhtml)				# til -> till (but not 'til which can look more natural in dialect)
-	xhtml = regex.sub(r"\b([Cc])heer", r"\1heer", xhtml)				# chear -> cheer
+	xhtml = regex.sub(r"\b([Cc])hear", r"\1heer", xhtml)				# chear -> cheer
 	xhtml = regex.sub(r"\bcentinel", r"sentinel", xhtml)				# centinel -> sentinel
 	xhtml = regex.sub(r"\bCentinel", r"Sentinel", xhtml)				# centinel -> sentinel
 	xhtml = regex.sub(r"\b([Ss])e’nnight", r"\1ennight", xhtml)			# se'nnight -> sennight
@@ -410,6 +412,20 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Tt])eaze", r"\1ease", xhtml)				# teaze -> tease
 	xhtml = regex.sub(r"\b([Cc])hrystal", r"\1rystal", xhtml)			# chrystal -> crystal
 	xhtml = regex.sub(r"\b([Pp])arty-?colo(u?)r", r"\1articolo\2r", xhtml)		# party-color -> particolor
+	xhtml = regex.sub(r"\b([Aa])ukward", r"\1wkward", xhtml)			# aukward -> awkward
+	xhtml = regex.sub(r"\b([Aa])lledg(ing|e[sd])", r"\1lleg\2", xhtml)		# alledge -> allege
+	xhtml = regex.sub(r"\b([Hh])er’s", r"\1ers", xhtml)				# her's -> hers
+	xhtml = regex.sub(r"\b([Pp])igm(y|ies)", r"\1ygm\2", xhtml)			# pigmy -> pygmy
+	xhtml = regex.sub(r"\bencreas", r"increas", xhtml)				# encreas(e|ing) -> increas(e|ing)
+	xhtml = regex.sub(r"\bEncreas", r"Increas", xhtml)				# encreas(e|ing) -> increas(e|ing)
+	xhtml = regex.sub(r"\b([Ee])nterpriz", r"\1nterpris", xhtml)			# enterprize -> enterprise
+	xhtml = regex.sub(r"\b([Ff])ye\b", r"\1ie", xhtml)				# fye -> fie
+	xhtml = regex.sub(r"\b([Cc])hace(s|d)?\b", r"\1hase\2", xhtml)			# chace -> chase
+	xhtml = regex.sub(r"\b([Ss])pight", r"\1pite", xhtml)				# spight -> spite
+	xhtml = regex.sub(r"\b([Ss])tedfast", r"\1teadfast", xhtml)			# stedfast -> steadfast
+	xhtml = regex.sub(r"\b([Rr])elique", r"\1elic", xhtml)				# relique -> relic
+	xhtml = regex.sub(r"\b([Ll])agune", r"\1agoon", xhtml)				# lagune -> lagoon
+	xhtml = regex.sub(r"\b([Ss])irup", r"\1yrup", xhtml)				# sirup -> syrup
 
 	# Normalize some names
 	xhtml = regex.sub(r"Moliere", r"Molière", xhtml)				# Moliere -> Molière
@@ -433,7 +449,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\bThibet", r"Tibet", xhtml)					# Thibet -> Tibet
 	xhtml = regex.sub(r"\bTimbuctoo", r"Timbuktu", xhtml)				# Timbuctoo -> Timbuktu
 	xhtml = regex.sub(r"\bTokio", r"Tokyo", xhtml)					# Tokio -> Tokyo
-	xhtml = regex.sub(r"\bTchekh?ov", r"Chekhov", xhtml)				# Tchekhov -> Chekhov
+	xhtml = regex.sub(r"\bT?[Cc]hekh?o(v|ff)", r"Chekhov", xhtml)			# Tchekhov/Chekov/Chekoff -> Chekhov
 	xhtml = regex.sub(r"\bVereshtchagin", r"Vereshchagin", xhtml)			# Vereshtchagin -> Vereshchagin
 	xhtml = regex.sub(r"\bSoudan", r"Sudan", xhtml)					# Soudan -> Sudan
 	xhtml = regex.sub(r"\bJack-in-the-box", r"jack-in-the-box", xhtml)		# Jack-in-the-box -> jack-in-the-box
@@ -460,6 +476,8 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"Burmah", r"Burma", xhtml)					# Burmah -> Burma
 	xhtml = regex.sub(r"Turgenieff", r"Turgenev", xhtml)				# Turgenieff -> Turgenev
 	xhtml = regex.sub(r"Gizeh", r"Giza", xhtml)					# Gizeh -> Giza
+	xhtml = regex.sub(r"Feejee", r"Fiji", xhtml)					# Feejee -> Fiji
+	xhtml = regex.sub(r"[YJ]edd?o\b", r"Edo", xhtml)				# Yeddo/Jeddo -> Edo
 
 	# Remove archaic diphthongs
 	xhtml = regex.sub(r"\b([Mm])edi(æ|ae)val", r"\1edieval", xhtml)
@@ -477,6 +495,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = xhtml.replace("Œdip", r"Oedip") # Oedipus, Oedipal
 	xhtml = regex.sub(r"\b([Pp])æan", r"\1aean", xhtml)
 	xhtml = regex.sub(r"\b([Vv])ertebræ", r"\1ertebrae", xhtml)
+	xhtml = xhtml.replace("Linnæus", r"Linnaeus")
 
 	# Remove spaces before contractions like `n’t` e.g. `is n’t` -> `isn’t`
 	xhtml = regex.sub(r" n’t\b", r"n’t", xhtml)
@@ -505,9 +524,11 @@ def modernize_spelling(xhtml: str) -> str:
 
 	# US spelling is unique
 	if language == "en-US":
+		xhtml = regex.sub(r"\b([Mm])anœuvred", r"\1aneuvered", xhtml)
 		xhtml = regex.sub(r"\b([Mm])anœuv(?:er|re)", r"\1aneuver", xhtml) # Omit last letter to catch both maneuverS and maneuverING
 		xhtml = regex.sub(r"\b([Mm])anœuvering", r"\1aneuvering", xhtml)
 	else:
+		xhtml = regex.sub(r"\b([Mm])anœuvred", r"\1anoeuvred", xhtml)
 		xhtml = regex.sub(r"\b([Mm])anœuv(?:er|re)", r"\1anoeuvre", xhtml)
 		xhtml = regex.sub(r"\b([Mm])anœuvring", r"\1anoeuvring", xhtml)
 		xhtml = regex.sub(r"\b([Mm])anoeuvreing", r"\1anoeuvring", xhtml)
